@@ -569,6 +569,10 @@ def collect_and_clean_annualitemdata(headless_conf=True, dryrun=False, subset=No
             scraped = ClassMapper.run_factory(f, driver)
             scraped.collect_clean_sequence()
             logger.debug("pre-clean, in collect_and_clean_annualitemdata")
+        except Exception as e:
+            logger.warning("FAILURE TO COLLECT FRANCHISE\n----------------------------\nfranchise {}, name {}, scraper {}; passed without"
+                " entry\nError:\n{}".format(f.id, f.name, f.nutr_scraper, e), exc_info=True)
+        try:
             df_obj = CollectedDf(f.name, f.id, scraped.nutr_df)
             df_obj.clean()
             df_obj.nutr_df = df_obj.nutr_df.where(pandas.notnull(df_obj.nutr_df), None)
@@ -579,7 +583,7 @@ def collect_and_clean_annualitemdata(headless_conf=True, dryrun=False, subset=No
             # df_obj.nutr_df.drop(columns="aid_objects", inplace=True)
             save_to_csv_for_review(df_obj.nutr_df, f.name, f.nutr_url, f.id, f.nutr_scraper, f.menu_scraper)
         except Exception as e:
-            logger.warning("Error for franchise {}, name {}; passed without"
+            logger.warning("FAILURE TO CLEAN FRANCHISE\n--------------------------\nfranchise {}, name {}; passed without"
                 " entry\nError:\n{}".format(f.id, f.name, e), exc_info=True)
     driver = None if driver == None else driver.quit()
 
@@ -705,7 +709,7 @@ def check_df_for_issues(name, df):
             issue_list.append(issue)
     if issue_list:
         issues = '\n'.join('{}' for _ in range(len(issue_list))).format(*issue_list)
-        logger.warning(f"ISSUES FOUND IN DF\n{name}\nissues:\n{issues}")
+        logger.warning(f"ISSUES FOUND FOR {name}\nissues:\n{issues}")
 
     # add condition to check number of entries without matches
 
