@@ -575,7 +575,7 @@ class Pdf(Scraper):
         return dfs
 
     def in_readconf(self, conf, val):
-        """Confirm that a value is in the config "operations" list.
+        """Confirm that a value is in the config "readconf" list.
         """
         if type(conf) is list:
             return True if val in conf[1] else False
@@ -774,7 +774,10 @@ class Pdf(Scraper):
         try:
             colvals = {"0":"item_name", "1":"menu_section"}
             rename_args = self.scraper_conf["col_setter"]
-            self.colnames_from_config(**rename_args)
+            if type(rename_args) is list:
+                self.colnames_from_config(name_list=rename_args)
+            elif type(rename_args) is dict:
+                self.colnames_from_config(**rename_args)
             self.nutr_df = self.nutr_df.rename(columns=colvals)
         # if "col_setter" doesn't exist, use "headers" rows to set values
         except Exception as e:
@@ -807,46 +810,50 @@ class Pdf(Scraper):
 
 
     # @wrap(writelog, writelog)
-    def colnames_from_config(self, m_s=1, serving=0, fat_cal=1,
-    potassium=0, switch_sodium_carb=False):
+    def colnames_from_config(self, m_s=0, serving=0, fat_cal=1,
+    potassium=0, switch_sodium_carb=False, name_list=None):
         """ Rename columns based on manually set parameters.
         Parameters:
         ----------
         nutr_df: dataframe
-        m_s: int, optional, defaults to 1
-            Index of column containing menu_section value. '0' means no column
-            will be relabeled as menu_section. col must come before all nutrition columns.
+        m_s: int, optional, defaults to 0
+            Index of menu_section column. '0' means no column will be relabeled 
+            as menu_section. col must come before all nutrition columns.
         serving: int, optional, defaults to 0
-            Index of column containing serving_size value. Setting
-            to 0 means there is no serving_size column.
+            Index of column containing serving_size value. Set to 0 if no
+            serving_size column is present.
         fat_cal: int, optional, defaults to 1
-            If a column corresponding to Calories from Fat is present in
-            df, value is 1; otherwise, set value to 0.
+            If a fat_calories column is present, set to 1; set to 0 if not.
         potassium: int, optional, defaults to 0
-            If a column corresponding to Potassium is present in df, set
-            value to 1; otherwise, value is 0.
+            If a potassium column is present, set value to 1.
         switch_sodium_carb: boolean, optional, defaults to False
             If carbohydrates column comes before sodium column, set to True.
+        name_list: list
+            An alternative approach. Simply list the names of all columns in order.
         """
-        six_seven = ["sodium", "carbohydrates"] if switch_sodium_carb == \
-                False else ["carbohydrates", "sodium"]
-        col_names = {
-        "{}".format(str(1+m_s+serving)):"calories",
-        "{}".format(str(2+m_s+fat_cal+serving)):"fat",
-        "{}".format(str(3+m_s+fat_cal+serving)):"saturated_fat",
-        "{}".format(str(4+m_s+fat_cal+serving)):"trans_fat",
-        "{}".format(str(5+m_s+fat_cal+serving)):"cholesterol",
-        "{}".format(str(6+m_s+fat_cal+serving)):six_seven[0],
-        "{}".format(str(7+m_s+fat_cal+serving+potassium)):six_seven[1],
-        "{}".format(str(8+m_s+fat_cal+serving+potassium)):"dietary_fiber",
-        "{}".format(str(9+m_s+fat_cal+serving+potassium)):"sugar",
-        "{}".format(str(10+m_s+fat_cal+serving+potassium)):"protein"
-        }
-        if potassium == 1:
-            col_names["{}".format(str(7+m_s+fat_cal+serving))] = "potassium"
-        if serving > 0:
-            col_names["{}".format(str(0+m_s+serving))] = "serving_size"
-        logger.debug(f"colnames_from_config rename dict:{col_names}")
+        if name_list != None:
+            col_names = dict(enumerate(name_list))
+            col_names = {str(k):v for k, v in col_names.items()}
+        else:
+            six_seven = ["sodium", "carbohydrates"] if switch_sodium_carb == \
+                    False else ["carbohydrates", "sodium"]
+            col_names = {
+            "{}".format(str(1+m_s+serving)):"calories",
+            "{}".format(str(2+m_s+fat_cal+serving)):"fat",
+            "{}".format(str(3+m_s+fat_cal+serving)):"saturated_fat",
+            "{}".format(str(4+m_s+fat_cal+serving)):"trans_fat",
+            "{}".format(str(5+m_s+fat_cal+serving)):"cholesterol",
+            "{}".format(str(6+m_s+fat_cal+serving)):six_seven[0],
+            "{}".format(str(7+m_s+fat_cal+serving+potassium)):six_seven[1],
+            "{}".format(str(8+m_s+fat_cal+serving+potassium)):"dietary_fiber",
+            "{}".format(str(9+m_s+fat_cal+serving+potassium)):"sugar",
+            "{}".format(str(10+m_s+fat_cal+serving+potassium)):"protein"
+            }
+            if potassium == 1:
+                col_names["{}".format(str(7+m_s+fat_cal+serving))] = "potassium"
+            if serving > 0:
+                col_names["{}".format(str(0+m_s+serving))] = "serving_size"
+            logger.debug(f"colnames_from_config rename dict:{col_names}")
         self.nutr_df = self.nutr_df.rename(columns=col_names)
 
 
